==> dice-0.1.1-142.1-loong64.pkg.tar.zst: usr/share/haskell/register/dice.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dice
version:              0.1.1
visibility:           public
id:                   dice-0.1.1-4G06GliI9br9SZVdH7rQ1P
key:                  dice-0.1.1-4G06GliI9br9SZVdH7rQ1P
license:              Unlicense
maintainer:           Naïm Favier <n@monade.li>
author:               James Cook <mokus@deepbondi.net>
stability:            work-in-progress
synopsis:             Simplistic D&D style dice-rolling system.
description:
    Simplistic D&D style dice-rolling system.

    > $ dice "2d10 + 2 * (d100 / d6)"
    > (5+2) + 2 * 64 / 2 => 71

category:             Game
abi:                  7ed6f0b35f394f0dae3c554b5b2a86b9
exposed:              True
exposed-modules:      Data.Random.Dice
import-dirs:          /usr/lib/ghc-9.6.6/site-local/dice-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dice-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dice-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dice
hs-libraries:         HSdice-0.1.1-4G06GliI9br9SZVdH7rQ1P
depends:
    base-4.18.2.1 mtl-2.3.1 parsec-3.1.16.1
    random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm
    random-fu-0.3.0.1-GYabAScmUtEAVvsb95PG2M

haddock-interfaces:   /usr/share/doc/dice/html/dice.haddock
haddock-html:         /usr/share/doc/dice/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dice-0.1.1-143-loong64.pkg.tar.zst: usr/share/haskell/register/dice.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dice
version:              0.1.1
visibility:           public
id:                   dice-0.1.1-Luih7IzIDwl5keCKErWXRm
key:                  dice-0.1.1-Luih7IzIDwl5keCKErWXRm
license:              Unlicense
maintainer:           Naïm Favier <n@monade.li>
author:               James Cook <mokus@deepbondi.net>
stability:            work-in-progress
synopsis:             Simplistic D&D style dice-rolling system.
description:
    Simplistic D&D style dice-rolling system.

    > $ dice "2d10 + 2 * (d100 / d6)"
    > (5+2) + 2 * 64 / 2 => 71

category:             Game
abi:                  3ffb6d73ec5def8b52a60854884946f0
exposed:              True
exposed-modules:      Data.Random.Dice
import-dirs:          /usr/lib/ghc-9.6.6/site-local/dice-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dice-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dice-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dice
hs-libraries:         HSdice-0.1.1-Luih7IzIDwl5keCKErWXRm
depends:
    base-4.18.2.1 mtl-2.3.1 parsec-3.1.16.1
    random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj
    random-fu-0.3.0.1-FjYoQXsLrVl4yb84CCphz8

haddock-interfaces:   /usr/share/doc/dice/html/dice.haddock
haddock-html:         /usr/share/doc/dice/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
